#!/bin/bash
# (c) Copyright 2007-2013 Hewlett Packard Development Company, L.P.
# Version A.12.00.00

#########################################################################
#
# Script that enables/disables and starts/stops a application Servers for
# SG/LX.  (As know as Toolkit Interface Script.)
#
# This script has one  parameter  passed to it, which then will be passed
# to the HA server main script:
#
#     - start   - to indicate the package is starting up
#     - stop    - to indicate the package is shutting down
#     - monitor - to indicate the package is monitoring the database. 
#
# This script eixt on one of the following code:
#  0: on success
#  1: on fail
#
#########################################################################




######################### VARIABLES & PARAMETERS ########################
#
# Variables      : Initialize the variables with suitable values. 
#                  
# HA_SCRIPT=<Path & Name of the Toolkit Main Script>
#
#                 This  variable  specifies  path and name of the toolkit
#                 Main script, to be invoked by this script.
#
# Arguments       :
#
#
# ACT = $1   :
#                 First parameter,  specifies the action to be taken viz.
#                 "start",   "stop"  or  "monitor".  Same   parameter  is
#                 forwarded to the Toolkit Main Script.
#
#########################################################################

PKG_DIR=${0%/*}

HA_SCRIPT="$PKG_DIR/hapgsql.sh"


ACT=$1



######################### FUNCTION HEADER ###############################
# Function Name  : test_return
#
# Description    : Queries the shell for the exit code of the previously 
#                  executed command. If error code queries is non-zero, 
#                  then the script exits with error.
#
#########################################################################

function test_return
{
    if (( $? != 0 ))
    then
        echo "$(date '+%b %e %T') - ERROR: Failed to $ACT PostgreSQL Server."
        exit 1
    fi
}


######################### FUNCTION HEADER ###############################
# Function Name  : log_info
#
# Description    : Function to log a warning message
#
#########################################################################

function log_info
{
    if [[ "$ACT" = "start" ]]
    then
        echo -e "$(date '+%b %e %T') - WARNING: The application script \"$HA_SCRIPT\" does not exist"
        echo -e "\t or is not executable. To run the application server on this node either"
        echo -e "\t copy the script to this package directory or use the chmod(1)"
        echo -e "\t command to make file $HA_SCRIPT executable. Then restart this package."
    else
        echo -e "$(date '+%b %e %T') - WARNING: The application control script \"$HA_SCRIPT\" does not exist or"
        echo -e "\t is not excutable. Either copy the script to this package directory"
        echo -e "\t or use the chmod(1) command to make file $HA_SCRIPT executable"
        echo -e "\t (You may need to manually clean application resources.)"
    fi

}


######################### FUNCTION HEADER ###############################
# Function Name  : test_return
#
# Description    : Function to invoke a application toolkit. and call 
#                  "log_info" or "test_return" for appropriate condition.
#
#########################################################################

# 
function invoke_app
{
    if [ -x $HA_SCRIPT ]; then
    #modified the script
        . $HA_SCRIPT $ACT
        test_return
    else
        log_info
    fi

    exit 0;
}


######################### STARTING POINT ###############################
#
# Description    : Invoke the Toolkit by calling "invoke_app" function.
#
#########################################################################

invoke_app

